@@ -87,8 +87,18 @@ if dpkg-architecture --is kfreebsd-any; then
 fi
 
 if dpkg-architecture -iany-s390x; then
-	# Target the oldest s390x supported by upstream
-	export CFLAGS="$CFLAGS -march=z10"
+	# Override CPU auto-detection, target the distro baseline
+	if dpkg-vendor --derives-from Ubuntu; then
+		gcc_pkg_version=$(dpkg-query -f '${Version}' -W gcc)
+		if dpkg --compare-versions $gcc_pkg_version ge 4:9; then
+			# Targetted z13 since gcc-9 9.2.1-12
+			export CFLAGS="$CFLAGS -march=z13"
+		else
+			export CFLAGS="$CFLAGS -march=zEC12"
+		fi
+	else
+		export CFLAGS="$CFLAGS -march=z196"
+	fi
 fi
 
 if echo "$PYTHON" | grep -Fq pypy; then
